@@ -1,6 +1,6 @@
 /*****
 *
-* Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 PreludeIDS Technologies. All Rights Reserved.
+* Copyright (C) 1998-2017 CS-SI. All Rights Reserved.
 * Author: Yoann Vandoorselaere <yoann.v@prelude-ids.com>
 *
 * This file is part of the Prelude-LML program.
@@ -15,9 +15,9 @@
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
-* You should have received a copy of the GNU General Public License
-* along with this program; see the file COPYING.  If not, write to
-* the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+* You should have received a copy of the GNU General Public License along
+* with this program; if not, write to the Free Software Foundation, Inc.,
+* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 *****/
 
@@ -730,6 +730,7 @@ static int parse_ruleset_directive(prelude_list_t *head, pcre_plugin_t *plugin,
         char *value;
         char *ptr = NULL;
         int first_directive = 1;
+        prelude_bool_t include_only = FALSE;
         pcre_rule_t *rule = NULL;
         pcre_rule_container_t *rc = NULL;
 
@@ -753,10 +754,21 @@ static int parse_ruleset_directive(prelude_list_t *head, pcre_plugin_t *plugin,
                         return -1;
                 }
 
+                if ( include_only ) {
+                       if ( strcmp(key, "include") == 0 ) {
+                               parse_include(NULL, plugin, value);
+                               continue;
+                       }
+
+                       prelude_log(PRELUDE_LOG_WARN, "%s:%d: ruleset starting with include should have only include directives.\n", filename, line);
+                       return -1;
+                }
+
                 if ( first_directive ) {
                         if ( strcmp(key, "include") == 0 ) {
                                 parse_include(NULL, plugin, value);
-                                return 0;
+                                include_only = TRUE;
+                                continue;
                         }
 
                         rule = create_rule();
@@ -775,6 +787,9 @@ static int parse_ruleset_directive(prelude_list_t *head, pcre_plugin_t *plugin,
                 }
         }
 
+        if ( include_only )
+                return 0;
+
         if ( prelude_list_is_empty(&rule->regex_list) ) {
                 prelude_log(PRELUDE_LOG_WARN, "%s:%d: rule does not provide a regex.\n", filename, line);
                 free_rule(rule);
@@ -856,7 +871,7 @@ static void pcre_run(prelude_plugin_instance_t *pi, const lml_log_source_t *ls,
         }
 
         if ( !(all_flags & PCRE_MATCH_FLAGS_ALERT) && plugin->dump_unmatched )
-                prelude_log(PRELUDE_LOG_WARN, "No alert emited for log entry \"%s\"\n",
+                prelude_log(PRELUDE_LOG_WARN, "No alert emitted for log entry \"%s\"\n",
                             lml_log_entry_get_message(log_entry));
 }
 
