@@ -1,6 +1,6 @@
 /*****
 *
-* Copyright (C) 1998-2005,2006,2007 PreludeIDS Technologies. All Rights Reserved.
+* Copyright (C) 1998-2017 CS-SI. All Rights Reserved.
 * Author: Yoann Vandoorselaere <yoann.v@prelude-ids.com>
 *
 * This file is part of the Prelude-LML program.
@@ -15,9 +15,9 @@
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
-* You should have received a copy of the GNU General Public License
-* along with this program; see the file COPYING.  If not, write to
-* the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+* You should have received a copy of the GNU General Public License along
+* with this program; if not, write to the Free Software Foundation, Inc.,
+* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 *****/
 
@@ -35,8 +35,6 @@
 #include <errno.h>
 #include <assert.h>
 
-#include <gcrypt.h>
-
 #ifdef HAVE_SYS_FILIO_H
 # include <sys/filio.h>
 #endif
@@ -54,6 +52,7 @@
 
 #include "ev.h"
 
+#include <libprelude/common.h>
 #include <libprelude/prelude.h>
 #include <libprelude/prelude-timer.h>
 #include <libprelude/prelude-log.h>
@@ -94,9 +93,6 @@
  */
 #define METADATA_CHECKSUM_SIZE 4
 #define METADATA_SIZE (sizeof(off_t) + METADATA_CHECKSUM_SIZE)
-#define METADATA_CHECKSUM_TYPE GCRY_MD_CRC32
-
-#define LOG_LINE_MAXSIZE 65535
 
 #define LOGFILE_RENAME_CLASS   "Log file rename"
 #define LOGFILE_DELETION_CLASS "Log file deletion"
@@ -322,14 +318,14 @@ static off_t read_logfile(monitor_fd_t *fd, off_t *available)
                 if ( ret == '\n' )
                         break;
 
-                if ( fd->current_line_len <= LOG_LINE_MAXSIZE ) {
+                if ( fd->current_line_len <= config.log_max_length ) {
                         ret = prelude_string_ncat(fd->buf, (const char *) &ret, 1);
                         if ( ret < 0 )
                                 prelude_log(PRELUDE_LOG_ERR, "error buffering input: %s.\n", prelude_strerror(ret));
                 }
 
-                else if ( fd->current_line_len == LOG_LINE_MAXSIZE + 1 )
-                        prelude_log(PRELUDE_LOG_WARN, "line too long (internal limit of %u characters).\n", LOG_LINE_MAXSIZE);
+                else if ( fd->current_line_len == config.log_max_length + 1 )
+                        prelude_log(PRELUDE_LOG_WARN, "line too long (configured limit of %u characters).\n", config.log_max_length);
 
                 if ( i == *available ) {
                         *available = 0;
@@ -372,6 +368,20 @@ static int file_metadata_read(monitor_fd_t *monitor, off_t *start, unsigned char
 }
 
 
+
+static void compute_checksum(const char *in, size_t insize, unsigned char *digest)
+{
+        uint32_t crc;
+
+        crc = prelude_crc32((const unsigned char *) in, insize);
+        digest[0] = (crc >> 24) & 0xff;
+        digest[1] = (crc >> 16) & 0xff;
+        digest[2] = (crc >>  8) & 0xff;
+        digest[3] = crc & 0xff;
+}
+
+
+
 static int file_metadata_save(monitor_fd_t *monitor, off_t offset)
 {
         int ret;
@@ -380,12 +390,10 @@ static int file_metadata_save(monitor_fd_t *monitor, off_t offset)
         if ( metadata_flags & FILE_SERVER_METADATA_FLAGS_NO_WRITE )
                 return 0;
 
-        assert(gcry_md_get_algo_dlen(METADATA_CHECKSUM_TYPE) + sizeof(offset) == sizeof(buf));
+        assert(METADATA_CHECKSUM_SIZE + sizeof(offset) == sizeof(buf));
 
         memcpy(buf, &offset, sizeof(offset));
-        gcry_md_hash_buffer(METADATA_CHECKSUM_TYPE, buf + sizeof(offset),
-                            prelude_string_get_string(monitor->buf),
-                            prelude_string_get_len(monitor->buf));
+        compute_checksum(prelude_string_get_string(monitor->buf), prelude_string_get_len(monitor->buf), buf + sizeof(offset));
 
         rewind(monitor->metadata_fd);
 
@@ -404,18 +412,19 @@ static int verify_metadata_checksum(prelude_string_t *log, unsigned char *metada
 {
         unsigned char sum[METADATA_CHECKSUM_SIZE];
 
-        assert(gcry_md_get_algo_dlen(METADATA_CHECKSUM_TYPE) == sizeof(sum));
-        gcry_md_hash_buffer(METADATA_CHECKSUM_TYPE, sum, prelude_string_get_string(log), prelude_string_get_len(log));
+        compute_checksum(prelude_string_get_string(log), prelude_string_get_len(log), sum);
 
         return memcmp(sum, metadata_sum, sizeof(sum));
 }
 
+
+
 static int file_metadata_get_position(monitor_fd_t *monitor)
 {
         struct stat st;
         const char *filename;
         int ret, have_metadata = 0;
-        off_t offset = 0, available = LOG_LINE_MAXSIZE;
+        off_t offset = 0, available = 65535;
         unsigned char msum[METADATA_SIZE], *sumptr = msum;
 
         filename = lml_log_source_get_name(monitor->source);
@@ -507,6 +516,7 @@ static int file_metadata_open(monitor_fd_t *monitor)
 }
 
 
+
 static int check_logfile_data(monitor_fd_t *monitor, struct stat *st)
 {
         off_t len, ret;
@@ -554,7 +564,7 @@ static int check_stdin_data(monitor_fd_t *monitor)
         int eventno = 0, bytes;
 
         if ( config.batch_mode )
-                len = LOG_LINE_MAXSIZE;
+                len = (off_t) config.log_max_length;
         else {
                 ret = ioctl(STDIN_FILENO, FIONREAD, &bytes);
                 if ( ret < 0 ) {
