@@ -1,6 +1,6 @@
 /*****
 *
-* Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005 PreludeIDS Technologies. All Rights Reserved.
+* Copyright (C) 1998-2017 CS-SI. All Rights Reserved.
 * Author: Yoann Vandoorselaere <yoann.v@prelude-ids.com>
 *
 * This file is part of the Prelude-LML program.
@@ -15,12 +15,14 @@
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
-* You should have received a copy of the GNU General Public License
-* along with this program; see the file COPYING.  If not, write to
-* the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+* You should have received a copy of the GNU General Public License along
+* with this program; if not, write to the Free Software Foundation, Inc.,
+* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 *****/
 
+#ifndef FILE_SERVER_PR_H
+#define FILE_SERVER_PR_H
 
 typedef enum {
         FILE_SERVER_METADATA_FLAGS_HEAD     = 0x01,
@@ -45,3 +47,5 @@ void file_server_set_max_rotation_time_offset(time_t val);
 off_t file_server_get_max_rotation_size_offset(void);
 
 void file_server_set_max_rotation_size_offset(off_t val);
+
+#endif
