@@ -1,6 +1,6 @@
 /*****
 *
-* Copyright (C) 2009 PreludeIDS Technologies. All Rights Reserved.
+* Copyright (C) 2009-2017 CS-SI. All Rights Reserved.
 * Author: Yoann Vandoorselaere <yoann.v@prelude-ids.com>
 *
 * This file is part of the Prelude-LML program.
@@ -15,12 +15,15 @@
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
-* You should have received a copy of the GNU General Public License
-* along with this program; see the file COPYING.  If not, write to
-* the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+* You should have received a copy of the GNU General Public License along
+* with this program; if not, write to the Free Software Foundation, Inc.,
+* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 *****/
 
+#ifndef LML_CHARSET_H
+#define LML_CHARSET_H
+
 typedef struct lml_charset lml_charset_t;
 
 int lml_charset_open(lml_charset_t **lc, const char *from);
@@ -30,3 +33,5 @@ int lml_charset_convert(lml_charset_t *lc, const char *in, size_t inlen, char **
 int lml_charset_detect(const char *in, size_t inlen, const char **out, int *confidence);
 
 int lml_charset_close(lml_charset_t *lc);
+
+#endif
