@@ -1,6 +1,6 @@
 /*****
 *
-* Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005 PreludeIDS Technologies. All Rights Reserved.
+* Copyright (C) 2000-2017 CS-SI. All Rights Reserved.
 * Author: Yoann Vandoorselaere <yoann.v@prelude-ids.com>
 *
 * This file is part of the Prelude-LML program.
@@ -15,29 +15,31 @@
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
-* You should have received a copy of the GNU General Public License
-* along with this program; see the file COPYING.  If not, write to
-* the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+* You should have received a copy of the GNU General Public License along
+* with this program; if not, write to the Free Software Foundation, Inc.,
+* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 *****/
 
-#ifndef _LML_PCONFIG_H
-#define _LML_PCONFIG_H
+#ifndef LML_OPTIONS_H
+#define LML_OPTIONS_H
 
 #include <libprelude/prelude-inttypes.h>
 #include "regex.h"
 #include "udp-server.h"
+#include "tcp-server.h"
 
 int lml_options_init(prelude_option_t *lml_optlist, int argc, char **argv);
 
 typedef struct {
         char *pidfile;
-        char *logfile_prefix_regex;
-        char *logfile_ts_format;
         const char *system_charset;
         char *charset;
         int charset_ref;
 
+        char *log_buffer;
+        unsigned int log_max_length;
+
         prelude_client_t *lml_client;
 
         prelude_bool_t batch_mode;
@@ -49,6 +51,12 @@ typedef struct {
         size_t udp_nserver;
         udp_server_t **udp_server;
 
+        size_t tcp_nserver;
+        tcp_server_t **tcp_server;
+
+        unsigned int tls_dh_bits;
+        unsigned int tls_dh_regenerate;
+
         prelude_io_t *text_output_fd;
         unsigned long alert_count;
         unsigned long line_processed;
@@ -58,4 +66,4 @@ typedef struct {
         gid_t wanted_gid;
 } lml_config_t;
 
-#endif /* _LML_PCONFIG_H */
+#endif
