@@ -1,6 +1,6 @@
 /*****
 *
-* Copyright (C) 2002, 2003, 2004, 2005 PreludeIDS Technologies. All Rights Reserved.
+* Copyright (C) 2002-2017 CS-SI. All Rights Reserved.
 * Author: Yoann Vandoorselaere <yoann.v@prelude-ids.com>
 *
 * This file is part of the Prelude-LML program.
@@ -15,9 +15,9 @@
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
-* You should have received a copy of the GNU General Public License
-* along with this program; see the file COPYING.  If not, write to
-* the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+* You should have received a copy of the GNU General Public License along
+* with this program; if not, write to the Free Software Foundation, Inc.,
+* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 *****/
 
@@ -59,7 +59,7 @@ static idmef_analyzer_t *idmef_analyzer;
 
 #define ANALYZER_CLASS "Log Analyzer"
 #define ANALYZER_MODEL "Prelude LML"
-#define ANALYZER_MANUFACTURER "http://www.prelude-ids.com"
+#define ANALYZER_MANUFACTURER "http://www.prelude-siem.com"
 
 
 
@@ -301,14 +301,14 @@ int lml_additional_data_prepare(prelude_list_t *adlist, const lml_log_source_t *
         if ( generate_additional_data(&adata, "Log received from", source, strlen(source)) < 0 )
                 return -1;
 
-        prelude_linked_object_add_tail(adlist, (prelude_linked_object_t *) adata);
+        idmef_object_add_tail(adlist, (idmef_object_t *) adata);
 
         ptr = lml_log_entry_get_original_log(log);
         if ( ptr ) {
                 if ( generate_additional_data(&adata, "Original Log", ptr, lml_log_entry_get_original_log_len(log)) < 0 )
                         return -1;
 
-                prelude_linked_object_add_tail(adlist, (prelude_linked_object_t *) adata);
+                idmef_object_add_tail(adlist, (idmef_object_t *) adata);
         }
 
         return 0;
