@@ -1,6 +1,6 @@
 /*****
 *
-* Copyright (C) 2003, 2004, 2005 PreludeIDS Technologies. All Rights Reserved.
+* Copyright (C) 2003-2017 CS-SI. All Rights Reserved.
 * Author: Yoann Vandoorselaere <yoann.v@prelude-ids.com>
 *
 * This file is part of the Prelude-LML program.
@@ -15,9 +15,9 @@
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
-* You should have received a copy of the GNU General Public License
-* along with this program; see the file COPYING.  If not, write to
-* the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+* You should have received a copy of the GNU General Public License along
+* with this program; if not, write to the Free Software Foundation, Inc.,
+* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 *****/
 
@@ -352,7 +352,7 @@ static lml_log_source_t *search_source(const char *name)
         lml_log_source_t *ls;
 
         prelude_list_for_each(&source_list, tmp) {
-                ls = prelude_linked_object_get_object(tmp);
+                ls = prelude_list_entry(tmp, lml_log_source_t, list);
 
                 if ( strcmp(lml_log_source_get_name(ls), name) == 0 )
                         return ls;
