@@ -1,6 +1,6 @@
 /*****
 *
-* Copyright (C) 2004, 2005 PreludeIDS Technologies. All Rights Reserved.
+* Copyright (C) 2004-2017 CS-SI. All Rights Reserved.
 * Author: Yoann Vandoorselaere <yoann.v@prelude-ids.com>
 *
 * This file is part of the Prelude-LML program.
@@ -15,9 +15,9 @@
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
-* You should have received a copy of the GNU General Public License
-* along with this program; see the file COPYING.  If not, write to
-* the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
+* You should have received a copy of the GNU General Public License along
+* with this program; if not, write to the Free Software Foundation, Inc.,
+* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 *****/
 
@@ -62,6 +62,7 @@
 
 #include "lml-options.h"
 #include "udp-server.h"
+#include "tcp-server.h"
 #include "file-server.h"
 #include "log-entry.h"
 #include "log-plugins.h"
@@ -71,6 +72,12 @@
  #define MAX(x, y) (((x) > (y)) ? (x) : (y))
 #endif
 
+
+typedef struct {
+        int pri;
+} syslog_header_t;
+
+
 struct regex_data {
         lml_log_source_t *log_source;
         lml_log_entry_t *log_entry;
@@ -95,7 +102,7 @@ static void print_stats(const char *prefix, struct timeval *end)
 
         tdiv = (end->tv_sec + (double) end->tv_usec / 1000000) - (start.tv_sec + (double) start.tv_usec / 1000000);
 
-        prelude_log(PRELUDE_LOG_WARN, "%s%lu line processed in %.2f seconds (%.2f EPS), %lu alert emited.\n",
+        prelude_log(PRELUDE_LOG_WARN, "%s%lu line(s) processed in %.2f second(s) (%.2f EPS), %lu alert(s) emitted.\n",
                     prefix, config.line_processed, tdiv, config.line_processed / tdiv, config.alert_count);
 }
 
@@ -113,6 +120,9 @@ static void server_close(void)
 
         for ( i = 0; i < config.udp_nserver; i++ )
                 udp_server_close(config.udp_server[i]);
+
+        for ( i = 0; i < config.tcp_nserver; i++ )
+                tcp_server_close(config.tcp_server[i]);
 }
 
 
@@ -197,7 +207,9 @@ void _lml_handle_signal_if_needed(void)
 #endif
 
         prelude_log(PRELUDE_LOG_WARN, "signal %d received, terminating prelude-lml.\n", signo);
-        exit(2);
+        ev_default_destroy();
+
+        exit((signo == SIGTERM) ? 0 : 1);
 }
 
 
@@ -213,6 +225,12 @@ static void libev_udp_cb(struct ev_io *w, int revents)
 }
 
 
+static void libev_tcp_accept_cb(struct ev_io *w, int revents)
+{
+        tcp_server_accept(w->data);
+}
+
+
 static void libev_interrupt_cb(EV_P_ ev_async *w, int revents)
 {
         _lml_handle_signal_if_needed();
@@ -227,6 +245,41 @@ static void regex_match_cb(void *plugin, void *data)
 
 
 
+static int logparse_pri(syslog_header_t *hdr, const char **src, size_t *len)
+{
+        size_t i = 0;
+        const char *ptr = *src;
+
+        hdr->pri = 0;
+
+        if ( ptr[i++] != '<' )
+                goto error;
+
+        while ( ptr[i] != '>' ) {
+                if ( ! isdigit(ptr[i]) )
+                        goto error;
+
+                hdr->pri = hdr->pri * 10 + (ptr[i++] - '0');
+        }
+
+        if ( ptr[i] == '>' && i >= 3 && i <= 4 ) {
+                *len -= i + 1;
+                *src += i + 1;
+                return 0;
+        }
+
+error:
+        /*
+         * If the relay receives a syslog message without a PRI, or with an
+         * unidentifiable PRI, then it MUST insert a PRI with a Priority value
+         * of 13
+         */
+        hdr->pri = 13;
+        return -1;
+}
+
+
+
 /**
  * lml_dispatch_log:
  * @list: List of regex.
@@ -240,14 +293,17 @@ void lml_dispatch_log(lml_log_source_t *ls, const char *str, size_t size)
 {
         int ret;
         char *out;
+        syslog_header_t hdr;
         struct regex_data rdata;
         lml_log_entry_t *log_entry;
 
+        logparse_pri(&hdr, &str, &size);
+
         ret = lml_log_source_preprocess_input(ls, str, size, &out, &size);
         if ( ret < 0 )
                 return;
 
-        prelude_log_debug(3, "[LOG] %s\n", out);
+        prelude_log_debug(3, "[LOG from=%s] %s\n", lml_log_source_get_name(ls), out);
 
         log_entry = lml_log_entry_new();
         if ( ! log_entry )
@@ -266,25 +322,36 @@ void lml_dispatch_log(lml_log_source_t *ls, const char *str, size_t size)
 }
 
 
+
 static void wait_for_event(void)
 {
         size_t i;
         int udp_event_fd;
-        ev_io events[config.udp_nserver];
+        int tcp_event_fd;
+        size_t nb_server = config.udp_nserver + config.tcp_nserver;
+        ev_io events[nb_server];
 
+        /* 
+         *  Initialize callback function for SIGHUP/SIGTERM/... events for interrupted running (daemonize or standalone)
+         */
         ev_async_init(&ev_interrupt, libev_interrupt_cb);
         ev_async_start(&ev_interrupt);
 
         for ( i = 0; i < config.udp_nserver; i++ ) {
                 udp_event_fd = udp_server_get_event_fd(config.udp_server[i]);
-
                 ev_io_init(&events[i], libev_udp_cb, udp_event_fd, EV_READ);
                 events[i].data = config.udp_server[i];
-
                 ev_io_start(&events[i]);
         }
 
-        ev_loop(0);
+        for ( ; i < config.udp_nserver + config.tcp_nserver; i++ ) {
+                tcp_event_fd = tcp_server_get_event_fd(config.tcp_server[i - config.udp_nserver]);
+                ev_io_init(&events[i], libev_tcp_accept_cb, tcp_event_fd, EV_READ);
+                events[i].data = config.tcp_server[i - config.udp_nserver];
+                ev_io_start(&events[i]);
+        }
+
+        ev_run(0);
 }
 
 
@@ -354,8 +421,8 @@ int main(int argc, char **argv)
 #endif
 
         ret = file_server_start_monitoring();
-        if ( ret < 0 && ! config.udp_nserver ) {
-                prelude_log(PRELUDE_LOG_WARN, "No file or UDP server available for monitoring: terminating.\n");
+        if ( ret < 0 && ! config.udp_nserver && ! config.tcp_nserver ) {
+                prelude_log(PRELUDE_LOG_WARN, "No file or UDP/TCP server available for monitoring: terminating.\n");
                 return -1;
         }
 
@@ -364,7 +431,7 @@ int main(int argc, char **argv)
                 if ( config.pidfile )
                         free(config.pidfile);
 
-                ev_default_fork();
+                ev_loop_fork(EV_DEFAULT);
         }
 
         ev_timer_init(&evt, libev_timer_cb, 1, 1);
